Skip to content

Insights

Updated: Nov 8, 2024

The Threads insights endpoints allow you to retrieve insights for Threads media objects and users. See Threads Insights API for more information.

GET /{threads-media-id}/insights

Retrieve insights for a Threads media object. See Media Insights for more information.

Parameters

NameDescription
access_token stringRequired. Threads Graph API user access token.
threads-media-id stringRequired. The path parameter of the Threads media identifier.
metric stringRequired. A comma-separated list of the metrics to be returned. Must be at least one of the metric values. Values: views, likes, replies, reposts, quotes, shares

GET /{threads-user-id}/threads_insights

Retrieve insights for a Threads user object. See User Insights for more information.

Parameters

NameDescription
access_token stringRequired. Threads Graph API user access token.
threads-user-id stringRequired. The path parameter of the Threads user identifier.
sinceOptional. Used in conjunction with the until parameter to define a range. If you omit since and until, it defaults to a 2-day range: yesterday through today. Format: Unix Timestamp
untilOptional. Used in conjunction with the since parameter to define a range. If you omit since and until, it defaults to a 2-day range: yesterday through today. Format: Unix Timestamp
metric stringRequired. A comma-separated list of the metrics to be returned. Must be at least one of the metric values. Values: views, likes, replies, reposts, quotes, clicks, followers_count, follower_demographics Note: follower_demographics is not compatible with the since and until parameters.

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About